# API Documentation of Bash Base Library

## error messages

### error-codes

```
error-codes (bash-ini)
# <50 .. reserved for base-base error-codes
#  51 .. illegal db-name
#  52 .. db named db-name not loaded
#  53 .. section not found
#  54 .. key not found
#  55 .. db named db-name already loaded
#  56 .. parse error
#  9x .. errors local to each function
```

### bini_string_of_error_code

```
bini_string_of_error_code
# returns string representation of error code
# errors: 2, 3
```

## accessing ini files

### bini_db_load

```
bini_db_load <db-name> <ini-file>
# loads contents of ini-file
# db-name must match ^[[:alnum:]_]+$ and must be currently unset
# errors: 2, 8, 9, 51, 55, 56
```

### bini_db_destroy

```
bini_db_destroy <db-name>
# destroys loaded ini db
# errors 2, 51
```

### bini_db_is_loaded

```
bini_db_is_loaded <db-name>
# check if db is loaded
# errors 2, 51, 52
```

## data access

### bini_key_exists

```
bini_key_exists <db-name> <key> [<section>]
# check if a key exists
# if no section is specified only global context is searched
# errors: 2, 51, 52, 53, 54
```

### bini_key_exists_with_default

```
bini_key_exists_with_default <db-name> <key> <section>
# like bini_key_exists but if section does exist and does not contain key it
# will search in global context
# errors: 2, 51, 52, 53, 54
```

### bini_section_exists

```
bini_section_exists <db-name> <section>
# check if a section exists
# errors: 2, 51, 52, 53
```

### bini_get_section_list

```
bini_get_section_list <retval-name> <db-name>
# return a list of all sections as array into global array <retval-name>
# retval-name must match ^[[:alpha:]][[:alnum:]_]*$
# note: the order is undefined
# errors: 2, 3, 51, 52
```

### bini_get_key_list

```
bini_get_key_list <retval-name> <db-name> [ <section> ]
# return a list of all keys as array into global array <retval-name>
# retval-name must match ^[[:alpha:]][[:alnum:]_]*$
# if no section is specified it will return keys found in global context
# note: the order is undefined
# errors: 2, 3, 51, 52, 53
```

### bini_get_value

```
bini_get_value <retval-name> <db-name> <key> [ <section> ]
# return value for <key> in <db-name> in optional <section>
# note: if <section> is specified key must exist in it
# note: <retval-name> must not start with '_'
# errors: 2, 3, 51, 52, 53, 54
```

### bini_get_value_with_default

```
bini_get_value_with_default <variablename> <db-name> <key> <section>
# return value for <key> in <db-name> in <section>
# or try global if <section> exists but does not contain key
# note: <retval-name> must not start with '_'
# errors: 2, 3, 51, 52, 53, 54
```
