<!-- -*- mode: markdown; mode: flyspell -*- -->

# bash-ini library

A library to query [ini style](https://en.wikipedia.org/wiki/INI_file)
configuration files. Currently there is no support to write or change
files on disk.

## Dependencies

bash-ini depends on bash-base

## API Documentation

The API Documentation can be found in [API.md](API.md).

## Using bash-ini

### Loading the Library

With loaded bash-base and system wide installed bash-ini all you have
to do is:
```
bb_require_libs bash-ini
```

Note: Using `bb_require_libs` will raise an fatal error if the library
could not be loaded. Use e.g. `bb_load_lib` to react on any error
while loading it.

## Namespace

All global variables and functions of bash-ini start with either
`bini_` or `_bini_`. Functions starting with `_bini_` are for
internal use only and their API might change without warning.

Function that take variable names as arguments will not accept
variable names starting with `_`. Local variables in bash-ini
function will always start with `_` or with the full function
name. That ensures that passed variable names will not be shadowed by
local variables inside the called function.

## Internals

### Parser

The ini file format is not standardized. bash-ini parses the following
file format:

1. Empty lines or comment lines (`^([[:space:]]*|[\;\#].*)$`) are ignored.
2. Any other line must be either a key value pair or a section definition
3. Section definitions must have the format `^\[([[:alnum:]_\-]([[:alnum:]\ _\-]*[[:alnum:]_\-])?)\][[:space:]]*$`
4. Key value pairs must have the format `^[[:space:]]*([[:alnum:]]([[:alnum:]\ _\-]*[[:alnum:]_\-])?)[[:blank:]]*=[[:blank:]]*(.*)[[:blank:]]*$`

## Example

The following ini file
```ini
; this is a comment
mainval1=take this
main val 2=this too
x = y

[sec1]
sec1val1=huhu  
sec1val2=haha		
  
# this is a comment, too	
[sec 2]
sec2val1=hoho der xmas man is do
	sec2val2=tab
	one and one = 	three it is   	  		  
```
is accessed by the following demo code:
```bash
#!/bin/bash

source /usr/libexec/bash-base.bash || {
    echo "$0: fatal error: failed to source /usr/libexec/bash-base.bash" >&2
    exit 1
}

# search for local file, fallback to system wide installation
bb_require_libs ./bash-ini.bash || \
    bb_require_libs bash-ini || \
    bb_fatal "could not load bash-ini lib"

function main() {
    bini_db_load demo "$1" || bb_fatal "bini_db_load demo '$1' failed: $?"

    local -a sections
    local val

    bini_get_section_list sections demo
    bb_msg info "lisit of all sections: ${sections[*]}"

    bini_get_value val demo mainval1
    bb_msg info "key 'mainval1' in global context: '$val'"
    
    bini_get_value val demo sec2val1 "sec 2"
    bb_msg info "key 'sec2val1' in section 'sec 2': '$val'"

    bini_get_value val demo "one and one" "sec 2"
    bb_msg info "key 'one and one' in section 'sec 2': '$val'"

    bb_quit
}

main demo.ini
```

<!--  LocalWords: ini Namespace API
 -->
